==> landing-page-webflow-scripts-2.8.2.tgz: package/src/util/format-utils.js <==
export class FormatUtils {
  static formatTimeSpan(from, to, includeSeconds) {
    const secondsTimeDifference = Math.floor((to.getTime() - from.getTime()) / 1000);

    if (secondsTimeDifference <= 0) {
      return '0 Sekunden';
    } else {
      let remainingTimeString = '';

      let timeDelta = secondsTimeDifference;

      const daysDifference = Math.floor(timeDelta / 86400);
      timeDelta -= daysDifference * 86400;
      const hoursDifference = Math.floor(timeDelta / 3600);
      timeDelta -= hoursDifference * 3600;
      const minutesDifference = Math.floor(timeDelta / 60);
      timeDelta -= minutesDifference * 60;
      const secondsDifference = Math.floor(timeDelta % 60);

      if (daysDifference > 0) {
        remainingTimeString += `${daysDifference} ${daysDifference > 1 ? 'Tage' : 'Tag'}`;
      }
      if (hoursDifference > 0) {
        if (remainingTimeString.length > 0) {
          remainingTimeString += ', ';
        }
        remainingTimeString += `${hoursDifference} ${hoursDifference > 1 ? 'Stunden' : 'Stunde'}`;
      }
      if (minutesDifference > 0 && daysDifference < 1) {
        if (remainingTimeString.length > 0) {
          remainingTimeString += ', ';
        }
        remainingTimeString += `${minutesDifference} ${minutesDifference > 1 ? 'Minuten' : 'Minute'}`;
      }

      if (includeSeconds) {
        if (daysDifference < 1 && hoursDifference < 1) {
          if (remainingTimeString.length > 0) {
            remainingTimeString += ', ';
          }
          remainingTimeString += `${secondsDifference} ${secondsDifference > 1 ? 'Sekunden' : 'Sekunde'}`;
        }
      } else {
        if (remainingTimeString.length === 0) {
          remainingTimeString += '< 1 Minute';
        }
      }

      return `${remainingTimeString}`.trim();
    }
  }

  static formatVehicleFuelType(fuelType) {
    switch (fuelType) {
      case 0:
        return 'Benzin';
      case 1:
        return 'Diesel';
      case 2:
        return 'Hybrid';
      case 3:
        return 'Elektrisch';
      case 4:
        return 'Autogas';
      case 5:
        return 'Andere';
      default:
        return 'Andere';
    }
  }

  static formatVehicleCategory(category) {
    switch (category) {
      case 0:
        return 'Limousine';
      case 1:
        return 'Kombi';
      case 2:
        return 'Kleinwagen';
      case 3:
        return 'Roadster/Cabrio';
      case 4:
        return 'Coupé';
      case 5:
        return 'Geländewagen';
      case 6:
        return 'Van';
      case 7:
        return 'Kastenwagen';
      case 8:
        return 'Pritschenwagen/Pick-Up';
      default:
        return 'Andere';
    }
  }

  static formatThumbnailUrl(url, width, height) {
    return url.replace('upload/', `upload/c_limit,h_${height},w_${width},fl_lossy,f_auto,q_auto/`);
  }

  static getCurrentWindowLocation() {
    return window.location.href;
  }
}

==> landing-page-webflow-scripts-2.8.6.tgz: package/src/util/format-utils.js <==
export class FormatUtils {
  static formatTimeSpan(from, to, includeSeconds) {
    const secondsTimeDifference = Math.floor((to.getTime() - from.getTime()) / 1000);

    if (secondsTimeDifference <= 0) {
      return '0 Sekunden';
    } else {
      let remainingTimeString = '';

      let timeDelta = secondsTimeDifference;

      const daysDifference = Math.floor(timeDelta / 86400);
      timeDelta -= daysDifference * 86400;
      const hoursDifference = Math.floor(timeDelta / 3600);
      timeDelta -= hoursDifference * 3600;
      const minutesDifference = Math.floor(timeDelta / 60);
      timeDelta -= minutesDifference * 60;
      const secondsDifference = Math.floor(timeDelta % 60);

      if (daysDifference > 0) {
        remainingTimeString += `${daysDifference} ${daysDifference > 1 ? 'days' : 'day'}`;
      }
      if (hoursDifference > 0) {
        if (remainingTimeString.length > 0) {
          remainingTimeString += ', ';
        }
        remainingTimeString += `${hoursDifference} ${hoursDifference > 1 ? 'hours' : 'hour'}`;
      }
      if (minutesDifference > 0 && daysDifference < 1) {
        if (remainingTimeString.length > 0) {
          remainingTimeString += ', ';
        }
        remainingTimeString += `${minutesDifference} ${minutesDifference > 1 ? 'minutes' : 'minute'}`;
      }

      if (includeSeconds) {
        if (daysDifference < 1 && hoursDifference < 1) {
          if (remainingTimeString.length > 0) {
            remainingTimeString += ', ';
          }
          remainingTimeString += `${secondsDifference} ${secondsDifference > 1 ? 'seconds' : 'second'}`;
        }
      } else {
        if (remainingTimeString.length === 0) {
          remainingTimeString += '< 1 Minute';
        }
      }

      return `${remainingTimeString}`.trim();
    }
  }

  static formatVehicleFuelType(fuelType) {
    switch (fuelType) {
      case 0:
        return 'Petrol';
      case 1:
        return 'Diesel';
      case 2:
        return 'Hybrid';
      case 3:
        return 'Eletric';
      case 4:
        return 'Autogas';
      case 5:
        return 'Other';
      default:
        return 'Other';
    }
  }

  static formatVehicleCategory(category) {
    switch (category) {
      case 0:
        return 'Sedan';
      case 1:
        return 'Estate car';
      case 2:
        return 'Compact car';
      case 3:
        return 'Roadster/Cabrio';
      case 4:
        return 'Coupé';
      case 5:
        return 'SUV';
      case 6:
        return 'Van';
      case 7:
        return 'Panel van';
      case 8:
        return 'Pick-Up';
      default:
        return 'Other';
    }
  }

  static formatThumbnailUrl(url, width, height) {
    return url.replace('upload/', `upload/c_limit,h_${height},w_${width},fl_lossy,f_auto,q_auto/`);
  }

  static getCurrentWindowLocation() {
    return window.location.href;
  }
}
